spacepy.data_assimilation.average_window — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »

# spacepy.data_assimilation.average_window

`spacepy.data_assimilation.` `average_window`(PSDdata, Lgrid)

  combine observations on same L shell in

  Parameters: | model : : PSDdata : : HAp : :
  Returns: | out : :

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »